==> kdepim-4.10.97.tar.xz: kdepim-4.10.97/pimsettingexporter/main.cpp <==
/*
  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/


#include "pimsettingexporterwindow.h"

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <KUniqueApplication>
#include <KDebug>
#include "kdepim-version.h"

int main(int argc, char *argv[])
{
    KLocale::setMainCatalog("pimsettingexporter");

    KAboutData aboutData( "pimsettingexporter", 0, ki18n("PIM Setting Exporter"),
                          KDEPIM_VERSION, ki18n("PIM Setting Exporter"), KAboutData::License_GPL_V2,
                          ki18n("Copyright © 2012-2013 pimsettingexporter authors"));
    aboutData.addAuthor(ki18n("Laurent Montel"), ki18n("Maintainer"), "montel@kde.org");
    aboutData.setProgramIconName(QLatin1String("kontact"));
    KCmdLineArgs::init( argc, argv, &aboutData );

    KCmdLineOptions options;
    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.

    KUniqueApplication::addCmdLineOptions();

    if (!KUniqueApplication::start())
    {
        kDebug() << "pimsettingexporter is already running!";
        return (0);
    }
    KUniqueApplication a;
    PimSettingExporterWindow *backupMailWin = new PimSettingExporterWindow();
    a.setTopWidget(backupMailWin);
    backupMailWin->show();

    return a.exec();
}

==> kdepim-4.14.2.tar.xz: kdepim-4.14.2/pimsettingexporter/main.cpp <==
/*
  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/


#include "pimsettingexporterwindow.h"
#include "pimsettingexporter_options.h"

#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <klocale.h>
#include <KUniqueApplication>
#include <KDebug>
#include "kdepim-version.h"

int main(int argc, char *argv[])
{
    KLocale::setMainCatalog("pimsettingexporter");

    KAboutData aboutData( "pimsettingexporter", 0, ki18n("PIM Setting Exporter"),
                          KDEPIM_VERSION, ki18n("PIM Setting Exporter"), KAboutData::License_GPL_V2,
                          ki18n("Copyright © 2012-2014 pimsettingexporter authors"));
    aboutData.addAuthor(ki18n("Laurent Montel"), ki18n("Maintainer"), "montel@kde.org");
    aboutData.setProgramIconName(QLatin1String("kontact"));
    KCmdLineArgs::init( argc, argv, &aboutData );

    KCmdLineArgs::addCmdLineOptions( pimsettingexporter_options() ); // Add our own options.

    KUniqueApplication::addCmdLineOptions();

    if (!KUniqueApplication::start())
    {
        kDebug() << "pimsettingexporter is already running!";
        return (0);
    }
    KUniqueApplication a;
    PimSettingExporterWindow *backupMailWin = new PimSettingExporterWindow();
    a.setTopWidget(backupMailWin);
    backupMailWin->show();
    backupMailWin->handleCommandLine();

    return a.exec();
}
